aboutsummaryrefslogtreecommitdiffstats
path: root/admin/update.php
diff options
context:
space:
mode:
Diffstat (limited to 'admin/update.php')
-rw-r--r--admin/update.php14
1 files changed, 13 insertions, 1 deletions
diff --git a/admin/update.php b/admin/update.php
index e4283a824..93e4f300f 100644
--- a/admin/update.php
+++ b/admin/update.php
@@ -116,10 +116,22 @@ SELECT galleries_url
// we need to have fulldirs as keys to make efficient comparison
$db_fulldirs = array_flip($db_fulldirs);
// finding next rank for each id_uppercat
$next_rank['NULL'] = 1;
$query = '
+SELECT id
+ FROM '.CATEGORIES_TABLE.'
+;';
+ $result = pwg_query($query);
+ while ($row = mysql_fetch_array($result))
+ {
+ $next_rank[$row['id']] = 1;
+ }
+
+ // let's see if some categories already have some sub-categories...
+ $query = '
SELECT id_uppercat, MAX(rank)+1 AS next_rank
FROM '.CATEGORIES_TABLE.'
GROUP BY id_uppercat
@@ -116,10 +116,22 @@ SELECT galleries_url
// we need to have fulldirs as keys to make efficient comparison
$db_fulldirs = array_flip($db_fulldirs);
- // finding next rank for each id_uppercat
+ // finding next rank for each id_uppercat. By default, each category id
+ // has 1 for next rank on its sub-categories to create
$next_rank['NULL'] = 1;
$query = '